import React, { useState, useRef, useEffect } from 'react';
import {
    ProForm,
    ProFormDigit,
    ProFormText,
    ProFormSelect,
    ProFormDateTimePicker
} from '@ant-design/pro-components';
import { FormattedMessage, useIntl } from '@umijs/max';
import { Form, Modal } from 'antd';
import moment from 'moment';
import Http from '@/utils/http';

const Edit = (props) => {
    const intl = useIntl();
    const [form] = Form.useForm();
    const { } = props;

    useEffect(() => {
        form.resetFields();
        form.setFieldsValue({
            ...props.values
        })
    }, [form, props])

    const handleCancel = () => {
        props.onCancel();
    };

    const handleOk = () => {
        form.submit();
    }

    const handleFinish = async (values) => {
        props.onSubmit({ ...values });
    }

    return (
        <>
            <Modal
                title="Edit"
                width={640}
                forceRender
                destroyOnClose
                open={props.open}
                onCancel={handleCancel}
                onOk={handleOk}
            >
                <ProForm
                    form={form}
                    submitter={false}
                    onFinish={handleFinish}
                    layout="horizontal"
                    grid={true}
                >
                    <ProFormDigit
                        name="id"
                        disabled
                        hidden={true}
                    />
                    <ProForm.Group>
                        <ProFormSelect
                            name="userId"
                            label="用户"
                            colProps={{ md: 12, xl: 12 }}
                            fieldProps={{ precision: 0 }}
                            placeholder="请选择"
                            rules={[{ required: true, message: "用户不能为空！" }]}
                            showSearch
                            debounceTime={300}
                            request={async ({ keyWords }) => {
                                const resp = await Http.doPostForm('api/user/query', { condition: keyWords });
                            return resp.data;
                            }}
                        />
                        <ProFormText
                            name="token"
                            label="密钥"
                            colProps={{ md: 12, xl: 12 }}
                            placeholder="请输入"
                        />
                    </ProForm.Group>
                    <ProForm.Group>
                        <ProFormText
                            name="ip"
                            label="登录ip"
                            colProps={{ md: 12, xl: 12 }}
                            placeholder="请输入"
                        />
                        <ProFormDigit
                            name="type"
                            label="类型"
                            colProps={{ md: 12, xl: 12 }}
                            fieldProps={{ precision: 0 }}
                            placeholder="请输入"
                        />
                    </ProForm.Group>
                    <ProForm.Group>
                        <ProFormDateTimePicker
                            name="createTime"
                            label="添加时间"
                            colProps={{ md: 12, xl: 12 }}
                            placeholder="请选择"
                            transform={(value) => moment(value).toISOString()}
                        />
                        <ProFormText
                            name="system"
                            label="登录系统"
                            colProps={{ md: 12, xl: 12 }}
                            placeholder="请输入"
                        />
                    </ProForm.Group>

                </ProForm>
            </Modal>
        </>
    )
}

export default Edit;
